@@ -1,7 +1,9 @@
 import sys
-sys.path.append('../notion2md')
+
+
+sys.path.append("../notion2md")
 
 if __name__ == "__main__":
     from .console import application
 
-    sys.exit(application.main())
\ No newline at end of file
+    sys.exit(application.main())
