@@ -1,5 +1,5 @@
 def error(msg):
-    return f"\n<error>{'ERRER'+' ':>12}</error>{msg}\n"
+    return f"\n<error>{'ERROR'+' ':>12}</error>{msg}\n"
 
 
 def status(status, msg):
