@@ -1,4 +1,5 @@
 import concurrent.futures
+import hashlib
 import os
 import urllib.request as request
 import uuid
@@ -21,6 +22,8 @@ class BlockConvertor:
         self._config = config
         self._client = client
         self._io = io
+        self._continued_numbered_list = False
+        self._numbered_list_number = 1
 
     def convert(self, blocks: dict) -> str:
         outcome_blocks: str = ""
@@ -32,14 +35,24 @@ class BlockConvertor:
     def convert_block(self, block: dict, depth=0) -> str:
         outcome_block: str = ""
         block_type = block["type"]
+        # Handle the case where the block is a list item
+        if block_type == "numbered_list_item":
+            if self._continued_numbered_list:
+                self._numbered_list_number += 1
+            else:
+                self._continued_numbered_list = True
+                self._numbered_list_number = 1
+        else:
+            self._continued_numbered_list = False
         # Special Case: Block is blank
         if (
             block_type == "paragraph"
             and not block["has_children"]
-            and not block[block_type]["text"]
+            and not block[block_type]["rich_text"]
         ):
-            outcome_block = blank() + "\n\n"
-        else:
+            return blank() + "\n\n"
+        # Normal Case
+        try:
             if block_type in BLOCK_TYPES:
                 outcome_block = (
                     BLOCK_TYPES[block_type](
@@ -48,39 +61,19 @@ class BlockConvertor:
                     + "\n\n"
                 )
             else:
-                outcome_block = f"[{block_type} is not supported]\n\n"
+                outcome_block = f"[//]: # ({block_type} is not supported)\n\n"
+            # Convert child block
             if block["has_children"]:
+                # create child page
                 if block_type == "child_page":
                     # call make_child_function
                     pass
+                # create table block
                 elif block_type == "table":
                     depth += 1
                     child_blocks = self._client.get_children(block["id"])
-                    table_list = []
-                    for cell_block in child_blocks:
-                        cell_block_type = cell_block["type"]
-                        table_list.append(
-                            BLOCK_TYPES[cell_block_type](
-                                self.collect_info(cell_block[cell_block_type])
-                            )
-                        )
-                    # convert to markdown table
-                    for index, value in enumerate(table_list):
-                        if index == 0:
-                            outcome_block = (
-                                " | " + " | ".join(value) + " | " + "\n"
-                            )
-                            outcome_block += (
-                                " | "
-                                + " | ".join(["----"] * len(value))
-                                + " | "
-                                + "\n"
-                            )
-                            continue
-                        outcome_block += (
-                            " | " + " | ".join(value) + " | " + "\n"
-                        )
-                    outcome_block += "\n"
+                    outcome_block = self.create_table(cell_blocks=child_blocks)
+                # create indent block
                 else:
                     depth += 1
                     child_blocks = self._client.get_children(block["id"])
@@ -88,12 +81,38 @@ class BlockConvertor:
                         outcome_block += "\t" * depth + self.convert_block(
                             block, depth
                         )
+        except Exception as e:
+            if self._io:
+                self._io.write_line(
+                    error(f"{e}: Error occured block_type:{block_type}")
+                )
         return outcome_block
 
+    def create_table(self, cell_blocks: dict):
+        table_list = []
+        for cell_block in cell_blocks:
+            cell_block_type = cell_block["type"]
+            table_list.append(
+                BLOCK_TYPES[cell_block_type](
+                    self.collect_info(cell_block[cell_block_type])
+                )
+            )
+        # convert to markdown table
+        for index, value in enumerate(table_list):
+            if index == 0:
+                table = " | " + " | ".join(value) + " | " + "\n"
+                table += (
+                    " | " + " | ".join(["----"] * len(value)) + " | " + "\n"
+                )
+                continue
+            table += " | " + " | ".join(value) + " | " + "\n"
+        table += "\n"
+        return table
+
     def collect_info(self, payload: dict) -> dict:
         info = dict()
-        if "text" in payload:
-            info["text"] = richtext_convertor(payload["text"])
+        if "rich_text" in payload:
+            info["text"] = richtext_convertor(payload["rich_text"])
         if "icon" in payload:
             info["icon"] = payload["icon"]["emoji"]
         if "checked" in payload:
@@ -120,19 +139,23 @@ class BlockConvertor:
         # table cells
         if "cells" in payload:
             info["cells"] = payload["cells"]
-
+        info["number"] = self._numbered_list_number
         return info
 
     def download_file(self, url: str) -> str:
         file_name = os.path.basename(urlparse(url).path)
         if self._config.download:
             if file_name:
-                name, extentsion = os.path.splitext(file_name)
+                name, extension = os.path.splitext(file_name)
 
-                if not extentsion:
+                if not extension:
                     return file_name, url
 
-                downloaded_file_name = str(uuid.uuid4())[:8] + extentsion
+                url_hash = hashlib.blake2s(
+                    urlparse(url).path.encode()
+                ).hexdigest()[:8]
+                downloaded_file_name = f"{url_hash}_{file_name}"
+
                 fullpath = os.path.join(
                     self._config.tmp_path, downloaded_file_name
                 )
@@ -194,7 +217,7 @@ def numbered_list_item(info: dict) -> str:
     """
     input: item:dict = {"number":int, "text":str}
     """
-    return f"1. {info['text']}"
+    return f"{info['number']}. {info['text']}"
 
 
 def to_do(info: dict) -> str:
